==> cms-db_v0.8.1.tar.gz: admin/locales/en/locale_frame.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['frame'] = array();

$locale['frame']['admin_logout'] = 'Do you really want to quit the admin area of cms -db?<br />All opened Tabs will be closed and the whole contents of the recycling center will be irrevocably deleted!';
$locale['frame']['button_menu'] = 'Menu';
$locale['frame']['button_update'] = 'Update available';
$locale['frame']['button_preview'] = 'Display website';
$locale['frame']['button_about'] = 'About cms -db';
$locale['frame']['button_desktop'] = 'Hide all tabs';
$locale['frame']['button_logout'] = 'Quit the admin area';
$locale['frame']['desc_no-js'] = 'Your browser doesn\'t support Javascript or it is disabled.';
$locale['frame']['link_no-js'] = 'Click here for an alternative version of cms -db without Javascripts.';
$locale['frame']['desc_ie-friendly'] = 'cms -db is supported by your browser but there may be minor problems or less features than in other browsers.';
$locale['frame']['desc_ie'] = 'Your browser doesn\'t support cms -db completely. There are multiple possiblities:';
$locale['frame']['link_better-browser'] = 'Use a better browser (recommended for best experience)';
$locale['frame']['link_newer-ie'] = 'Update your browser using Windows Update (recommended)';
$locale['frame']['link_quirksmode'] = 'Use the compatibility version';
$locale['frame']['link_fullversion'] = 'Use the full version with restrictions';
$locale['frame']['desc_update-available'] = 'An update to version %s is available. If you want to install it please download the package and log out. After copying the files to the server the update must be finished by logging in as main user.';
$locale['frame']['desc_update-available-auto'] = 'An update to version %s is available. It will be automatically downloaded and installed.';
$locale['frame']['button_download'] = 'Download';
$locale['frame']['button_more-info'] = 'More information';

$locale['frame']['desc_compatversion'] = 'Compatibility Version';
?>

==> cms-db_v0.9.tar.gz: admin/locales/en/locale_frame.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['frame'] = array();

$locale['frame']['admin_logout'] = 'Do you really want to quit the admin area of cms -db?<br />All opened Tabs will be closed and the whole contents of the recycling center will be irrevocably deleted!';
$locale['frame']['button_menu'] = 'Menu';
$locale['frame']['button_update'] = 'Update available';
$locale['frame']['button_update-none'] = 'Up to date';
$locale['frame']['button_update-manual'] = 'Update Management';
$locale['frame']['button_preview'] = 'Display website';
$locale['frame']['button_about'] = 'About cms -db';
$locale['frame']['button_desktop'] = 'Hide all tabs';
$locale['frame']['button_logout'] = 'Quit the admin area';
$locale['frame']['desc_no-js'] = 'Your browser doesn\'t support Javascript or it is disabled.';
$locale['frame']['link_no-js'] = 'Click here for an alternative version of cms -db without Javascripts.';
$locale['frame']['desc_ie-friendly'] = 'cms -db is supported by your browser but there may be minor problems or less features than in other browsers.';
$locale['frame']['desc_ie'] = 'Your browser doesn\'t support cms -db completely. There are multiple possiblities:';
$locale['frame']['link_better-browser'] = 'Use a better browser (recommended for best experience)';
$locale['frame']['link_newer-ie'] = 'Update your browser using Windows Update (recommended)';
$locale['frame']['link_quirksmode'] = 'Use the compatibility version';
$locale['frame']['link_fullversion'] = 'Use the full version with restrictions';

$locale['frame']['desc_compatversion'] = 'Compatibility Version';
?>
